@@ -1,13 +1,13 @@
 # Register the custom dialect
 from sqlalchemy.dialects import registry as _registry
 
-__version__ = "1.0.34"
+__version__ = "1.0.45"
 
 _registry.register(
     "dhis2", "sqlalchemy_dhis2.jsonhttp_dialect", "JSONHTTPDialect"
 )
 
-from sqlalchemy_dhis2.connection import connect
+#from sqlalchemy_dhis2.connection import connect
 from sqlalchemy_dhis2.exceptions import (
     DataError,
     DatabaseError,
@@ -25,7 +25,7 @@ from sqlalchemy_dhis2.exceptions import (
 
 
 __all__ = [
-    'connect',
+    #'connect',
     'apilevel',
     'threadsafety',
     'paramstyle',
